﻿#region License
/*
Kangaroo Library for C# and .NET
Copyright (c) 2013 Dimension Engineering LLC
http://www.dimensionengineering.com/kangaroo

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted, provided that the above
copyright notice and this permission notice appear in all copies.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY
SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER
RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT,
NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE
USE OR PERFORMANCE OF THIS SOFTWARE.
*/
#endregion

using System;
using System.Threading;
using DimensionEngineering.Kangaroo;

// USB TTL Serial TX  goes to Kangaroo S1
// USB TTL Serial RX  goes to Kangaroo S2
// USB TTL Serial GND goes to Kangaroo 0V
// Make sure to change the PortName constant.

namespace Examples.SpeedControl
{
    class Program
    {
        const string PortName = "COM148"; // <-- Your serial port name goes here (COM1, COM2, etc.).

        static KangarooSerial K;
        static KangarooChannel K1;
        static KangarooChannel K2;

        static void Setup()
        {
            K = new KangarooSerial();
            K.Open(PortName);

            K1 = new KangarooChannel(K, '1');
            K2 = new KangarooChannel(K, '2');

            K1.Start();
            K1.Home().Wait();
        }

        static void Loop()
        {
            int minimum = K1.GetMin().Value;
            int maximum = K1.GetMax().Value;
            int speed = (maximum - minimum) / 10; // Go 1/10th of the range per second.

            K1.S(speed).Wait();
            Thread.Sleep(5000);

            K1.S(-speed).Wait();
            Thread.Sleep(5000);
        }

        static void Main(string[] args)
        {
            Setup();
            while (true) { Loop(); }
        }
    }
}
