﻿#region License
/*
Kangaroo Library for C# and .NET
Copyright (c) 2014 Dimension Engineering LLC
http://www.dimensionengineering.com/kangaroo

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted, provided that the above
copyright notice and this permission notice appear in all copies.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY
SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER
RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT,
NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE
USE OR PERFORMANCE OF THIS SOFTWARE.
*/
#endregion

using System;
using System.Threading;
using DimensionEngineering.Kangaroo;

// USB TTL Serial TX  goes to Kangaroo S1
// USB TTL Serial RX  goes to Kangaroo S2
// USB TTL Serial GND goes to Kangaroo 0V
// Make sure to change the PortName constant.

namespace Examples.Streaming
{
    class Program
    {
        const string PortName = "COM203"; // <-- Your serial port name goes here (COM1, COM2, etc.).

        static KangarooSerial K;
        static KangarooChannel K1;
        static KangarooChannel K2;

        static void Setup()
        {
            K = new KangarooSerial();
            K.Open(PortName);

            K1 = new KangarooChannel(K, '1');
            K2 = new KangarooChannel(K, '2');

            K1.Start();
            K1.Home().Wait();
        }

        static void Loop()
        {
            int minimum = K1.GetMin().Value;
            Console.WriteLine("Minimum: {0}", minimum);

            int maximum = K1.GetMax().Value;
            Console.WriteLine("Maximum: {0}", maximum);

            // Start at the minimum position.
            K1.P(minimum).Wait();

            // Enable streaming for this motion.
            // This will *massively* improve our update rate at the cost of not checking if each intermediate command
            // is received. Since we will be continually sending the commands, we won't need this checking.
            K1.Streaming = true;

            // Let's do a parabolic shape in 20 seconds, 20 milliseconds at a time.
            for (double t = 0; t <= 20; t += 0.020)
            {
                double x = t / 20;
                double y = 4 * x * (1 - x);
                int p = (int)Math.Round(minimum + (maximum - minimum) * y);
                Console.WriteLine("P: {0}", p);
                K1.P(p);
                Thread.Sleep(20);
            }

            // We're about to do a command with a Wait(), so turn streaming off again.
            K1.Streaming = false;

            // Wait to get to the minimum position again.
            K1.P(minimum).Wait();
        }

        static void Main(string[] args)
        {
            Setup();
            while (true) { Loop(); }
        }
    }
}
