﻿#region License
/*
Kangaroo Library for C# and .NET
Copyright (c) 2013 Dimension Engineering LLC
http://www.dimensionengineering.com/kangaroo

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted, provided that the above
copyright notice and this permission notice appear in all copies.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY
SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER
RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT,
NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE
USE OR PERFORMANCE OF THIS SOFTWARE.
*/
#endregion

namespace DimensionEngineering.Kangaroo
{
    /// <summary>
    /// Errors that can occur in response to status queries.
    /// </summary>
    public enum KangarooError
    {
        /// <summary>
        /// No error occurred.
        /// </summary>
        None = 0x00,

        /// <summary>
        /// The channel is not started. Call <see cref="KangarooChannel.Start"/> on the channel.
        /// </summary>
        NotStarted = 0x01,

        /// <summary>
        /// The channel needs to be homed. Call <see cref="KangarooChannel.Home"/> on the channel.
        /// </summary>
        NotHomed = 0x02,

        /// <summary>
        /// A control error has occurred. Call <see cref="KangarooChannel.Start"/> on the channel to clear the control error.
        /// </summary>
        ControlError = 0x03,

        /// <summary>
        /// The controller is in the wrong mode. For example, the DIP switches may be in Mixed Mode while the tune was done in Independent Mode.
        /// </summary>
        WrongMode = 0x04,

        UnrecognizedCode = 0x05,

        /// <summary>
        /// A serial timeout occurred, or the TX line was disconnected. Call <see cref="KangarooChannel.Start"/> on the channel to clear the serial timeout.
        /// </summary>
        SerialTimeout = 0x06,

        InvalidStatus = -0x01,

        /// <summary>
        /// The requested timeout expired.
        /// </summary>
        TimedOut = -0x02,

        /// <summary>
        /// The serial port is not open.
        /// </summary>
        PortNotOpen = -0x03
    }
}
