﻿#region License
/*
Kangaroo Library for C# and .NET
Copyright (c) 2013 Dimension Engineering LLC
http://www.dimensionengineering.com/kangaroo

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted, provided that the above
copyright notice and this permission notice appear in all copies.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY
SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER
RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT,
NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE
USE OR PERFORMANCE OF THIS SOFTWARE.
*/
#endregion

using System;

namespace DimensionEngineering.Kangaroo
{
    struct KangarooReplyReader
    {
        byte[] _buffer;
        int _offset;
        int _count;

        public KangarooReplyReader(byte[] buffer, int offset, int count)
        {
            if (buffer == null) { throw new ArgumentNullException("buffer"); }
            if (offset < 0 || offset > buffer.Length) { throw new ArgumentOutOfRangeException("offset"); }
            if (count < 0 || count > buffer.Length - offset) { throw new ArgumentOutOfRangeException("count"); }

            _buffer = buffer; _offset = offset; _count = count;
        }

        public byte Read()
        {
            byte value = _buffer[_offset];
            _offset++; _count--; return value;
        }

        public bool TryRead(out byte value)
        {
            if (CanRead) { value = Read(); return true; } else { value = 0; return false; }
        }

        public int ReadBitPackedNumber()
        {
	        uint encodedNumber = 0; int shift = 0;

	        for (byte i = 0; i < 5; i ++) // 30 bits
	        {
		        byte @byte;
		        if (!TryRead(out @byte)) { break; }
		
		        encodedNumber |= (uint)(@byte & 0x3f) << shift; shift += 6;
		        if (0 == (@byte & 0x40)) { break; }
	        }

	        return 0 != (encodedNumber & 1) ? -(int)(encodedNumber >> 1) : (int)(encodedNumber >> 1);
        }

        public bool CanRead
        {
            get { return _count != 0; }
        }
    }
}
